@@ -1,6 +1,7 @@
+#include "util/xc_stack.h"
 
 ZEND_BEGIN_MODULE_GLOBALS(xcache)
-	zend_bool initial_compile_file_called; /* true is origin_compile_file is called */
+	zend_bool initial_compile_file_called; /* true if origin_compile_file is called */
 	zend_bool cacher;      /* true if enabled */
 	zend_bool stat;
 	zend_bool experimental;
@@ -9,16 +10,27 @@ ZEND_BEGIN_MODULE_GLOBALS(xcache)
 #endif
 #ifdef HAVE_XCACHE_COVERAGER
 	zend_bool coverager;
-	zend_bool coverage_enabled;
+	zend_bool coverager_autostart;
+	zend_bool coverager_started;
 	HashTable *coverages;  /* coverages[file][line] = times */
 #endif
 	xc_stack_t *php_holds;
+	zend_uint php_holds_size;
 	xc_stack_t *var_holds;
+	zend_uint var_holds_size;
 	time_t request_time;
 	long   var_ttl;
-	zend_bool auth_enabled;
+#ifdef IS_UNCODE
+	zval uvar_namespace_hard;
+	zval uvar_namespace_soft;
+#endif
+	zval var_namespace_hard;
+	zval var_namespace_soft;
 
 	zend_llist gc_op_arrays;
+#ifdef ZEND_ACC_ALIAS
+	zend_llist gc_class_entries;
+#endif
 
 #ifdef HAVE_XCACHE_CONSTANT
 	HashTable internal_constant_table;
